:mod:`nilearn.utils`: Utilities
===============================

.. automodule:: nilearn.utils
   :no-members:
   :no-inherited-members:

.. No relevant user manual section yet.


:mod:`nilearn.utils`
--------------------

.. currentmodule:: nilearn.utils

.. autosummary::
   :toctree: generated/
   :template: function.rst

   all_displays
   all_estimators
   all_functions
